| Title: | Global Plant Growth Form: a dynamically-updating versioned growth form data for vascular plants |
|---|---|
| Description: | A growth form database for >145,000 species of vascular plants. |
| Authors: | Will Cornwell [aut, cre] |
| Maintainer: | Will Cornwell <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.3 |
| Built: | 2026-05-24 10:00:45 UTC |
| Source: | https://github.com/traitecoevo/growthform |
Lookup table for plant growth form
growth_form(version = NULL) growth_form_versions(local = TRUE) growth_form_version_current_local(local = TRUE) growth_form_version_current_github(local = FALSE) get_most_recent_growth_form() growth_form_del(version)growth_form(version = NULL) growth_form_versions(local = TRUE) growth_form_version_current_local(local = TRUE) growth_form_version_current_github(local = FALSE) get_most_recent_growth_form() growth_form_del(version)
version |
Version number. The default will load the most
recent version on your computer or the most recent version known
to the package if you have never downloaded the data before.
With |
local |
Type of version to return: options are "local"
(versions installed locally) or "github" (versions available on
github). With any luck, "github" is a superset of "local". For
|
These data are then currated–please flag any errors or potential additions on github are at https://github.com/wcornwell/growthformdatabase
# # see the format of the resource # head(growth_form())# # see the format of the resource # head(growth_form())
Build a lookup table for a set of species, connecting the species names to growth form
growth_form_lookup_table(species_list, lookup_table = NULL, version = NULL)growth_form_lookup_table(species_list, lookup_table = NULL, version = NULL)
species_list |
Character vector of species bionomials Genus and species may be seperated by " " or "_" |
lookup_table |
Any growth form lookup table, but by default |
version |
Version number. The default will load the most
recent version on your computer or the most recent version known
to the package if you have never downloaded the data before.
With |